#!/usr/bin/env python
# -*- coding:utf-8 -*-
import pygtk
pygtk.require('2.0')
import gtk

class ExempleUIFusion:
    ui0 = '''<ui>
    <menubar name="BarreMenu">
      <menu action="Fichier">
        <menuitem action="Quitter"/>
      </menu>
      <menu action="Son">
        <menuitem action="Volume"/>
      </menu>
      <menu action="Modulation">
        <menuitem action="MA"/>
        <menuitem action="MF"/>
        <menuitem action="BLU"/>
      </menu>
    </menubar>
    <toolbar name="BarreOutils">
      <toolitem action="Quitter"/>
      <separator/>
      <toolitem action="Volume"/>
      <separator name="sep1"/>
      <placeholder name="ElementsMod">
        <toolitem action="MA"/>
        <toolitem action="MF"/>
        <toolitem action="BLU"/>
      </placeholder>
    </toolbar>
    </ui>'''
      
    ui1 = '''<ui>
    <menubar name="BarreMenu">
      <menu action="Fichier">
        <menuitem action="Enregistrer" position="top"/>
        <menuitem action="Nouveau" position="top"/>
      </menu>
      <menu action="Son">
        <menuitem action="Intensite"/>
      </menu>
      <menu action="Modulation">
        <menuitem action="CB"/>
        <menuitem action="OndesCourtes"/>
      </menu>
    </menubar>
    <toolbar name="BarreOutils">
      <toolitem action="Enregistrer" position="top"/>
      <toolitem action="Nouveau" position="top"/>
      <separator/>
      <toolitem action="Intensite"/>
      <separator/>
      <placeholder name="ElementsMod">
        <toolitem action="CB"/>
        <toolitem action="OndesCourtes"/>
      </placeholder>
    </toolbar>
    </ui>'''
      
    def __init__(self):
        # Créer la fenêtre de premier niveau
        fenetre = gtk.Window()
        fenetre.connect('destroy', lambda w: gtk.main_quit())
        fenetre.set_size_request(800, -1)
        vbox = gtk.VBox()
        fenetre.add(vbox)

        self.fusion_id = 0

        # Créer une instance du UIManager
        gestionui = gtk.UIManager()
        self.gestionui = gestionui

        # Ajouter le groupe de raccourcis à la fenêtre de premier niveau
        grouperacc = gestionui.get_accel_group()
        fenetre.add_accel_group(grouperacc)

        # Créer le ActionGroup principal
        groupeactions0 = gtk.ActionGroup('ExempleUIFusionBase')

        groupeactions0.add_actions([('Fichier', None, '_Fichier'),
                                  ('Son', None, '_Son'),
                                  ('Modulation', None, '_Modulation')])
        gestionui.insert_action_group(groupeactions0, 0)

        # Créer un ActionGroup
        groupeactions = gtk.ActionGroup('ExempleUIFusionBase')
        self.groupeactions = groupeactions

        # Créer une ToggleAction, etc.
        groupeactions.add_toggle_actions([('Volume', None, '_Volume', '<Control>v',
                                         'Niveau de son', self.rappel_volume)])

        # Créer les actions
        groupeactions.add_actions([('Quitter', gtk.STOCK_QUIT, '_Quitter moi !', None,
                                  'Quitter the Program', self.rappel_quitte)])
        groupeactions.get_action('Quitter').set_property('short-label', '_Quitter')

        # Créer quelques RadioActions
        groupeactions.add_radio_actions([('MA', None, '_MA', '<Control>m',
                                        "Modulation d'amplitude", 0),
                                       ('MF', None, 'M_F', '<Control>f',
                                        'Modulation de fréquence', 1),
                                       ('BLU', None, '_BLU', '<Control>b',
                                        'Bande latérale unique', 2),
                                       ], 0, self.rappel_modulation)

        # Ajouter le groupe d'action au gestionnaire d'interface
        gestionui.insert_action_group(groupeactions, 1)

        # Ajouter une description d'Interface Utilisateur
        fusion_id = gestionui.add_ui_from_string(self.ui0)

        # Créer un autre groupe d'actions et y ajouter les actions
        groupeactions1 = gtk.ActionGroup('ExempleUIFusionExtras')
        groupeactions1.add_toggle_actions([('Intensite', None, '_Intensité',
                                          '<Control>i', 'Correction intensité',
                                          self.rappel_intensite)])
        groupeactions1.add_actions([('Nouveau', gtk.STOCK_NEW, None, None,
                                   'Nouveaux paramètres', self.rappel_nouveau),
                                  ('Enregistrer', gtk.STOCK_SAVE, None, None,
                                   'Enregistrer paramètres', self.rappel_sauve)])
        # Adding radioactions to existing radioactions requires setting the
        # group and making sure the values are unique and the actions are
        # not active
        groupeactions1.add_radio_actions([('CB', None, '_CB', '<Control>c',
                                         'Cibi', 3),
                                       ('OndesCourtes', None, '_Ondes courtes',
                                        '<Control>o', 'Ondes courtes', 4),
                                       ], 3, self.rappel_modulation)
        group = groupeactions.get_action('MA').get_group()[0]
        action = groupeactions1.get_action('CB')
        action.set_group(group)
        action.set_active(False)
        action = groupeactions1.get_action('OndesCourtes')
        action.set_group(group)
        action.set_active(False)

        # Ajouter le groupe d'action supplémentaire au gestionnaire d'interface
        gestionui.insert_action_group(groupeactions1, 2)

        # Créer une barre de menus BarreMenu
        barremenus = gestionui.get_widget('/BarreMenu')
        vbox.pack_start(barremenus, False)

        # Créer une barre d'outils
        barreoutils = gestionui.get_widget('/BarreOutils')
        vbox.pack_start(barreoutils, False)

        # Créer et placer deux étiquettes
        label = gtk.Label('Son non établi')
        vbox.pack_start(label)
        self.textevolume = label
        label = gtk.Label('Mode MA')
        vbox.pack_start(label)
        self.bandlabel = label

        # Créer les boutons pour contrôler la sensibilité et la visibilité des actions
        buttonbox = gtk.HButtonBox()
        boutonsensible = gtk.CheckButton('Sensible')
        boutonsensible.set_active(True)
        boutonsensible.connect('toggled', self.change_sensible)
        boutonvisible = gtk.CheckButton('Visible')
        boutonvisible.set_active(True)
        boutonvisible.connect('toggled', self.change_visible)
        boutonfusion = gtk.CheckButton('Fusionner')
        boutonfusion.set_active(False)
        boutonfusion.connect('toggled', self.choix_fusion)
        # les ajouter à la boîte à boutons
        buttonbox.pack_start(boutonsensible, False)
        buttonbox.pack_start(boutonvisible, False)
        buttonbox.pack_start(boutonfusion, False)
        vbox.pack_start(buttonbox)
        print gestionui.get_ui()
        fenetre.show_all()
        return

    def rappel_volume(self, action):
        # action n'est pas encore réalisée
        texte = ('établi', 'non établi')[action.get_active()==False]
        self.textevolume.set_text('Son %s' % texte)
        return

    def rappel_intensite(self, action):
        # action n'est pas encore réalisée
        print 'Correcteur Intensité modifié'
        return

    def rappel_modulation(self, action, current):
        texte = current.get_name()
        self.bandlabel.set_text('Mode %s' % texte)
        return

    def rappel_nouveau(self, b):
        print 'Nouveaux paramètres'
        return

    def rappel_sauve(self, b):
        print 'Enregistrer les paramètres'
        return

    def rappel_quitte(self, b):
        print 'Quitter le programme'
        gtk.main_quit()

    def change_sensible(self, b):
        self.groupeactions.set_sensitive(b.get_active())
        return

    def change_visible(self, b):
        self.groupeactions.set_visible(b.get_active())
        return

    def choix_fusion(self, b):
        if self.fusion_id:
            self.gestionui.remove_ui(self.fusion_id)
            self.fusion_id = 0
        else:
            self.fusion_id = self.gestionui.add_ui_from_string(self.ui1)
            print 'id fusion :', self.fusion_id
        print self.gestionui.get_ui()
        return

if __name__ == '__main__':
    ba = ExempleUIFusion()
    gtk.main()
